==> jquery_countdown-6.x-1.0.tar.gz: jquery_countdown/jquery_countdown.js <==
// $Id: jquery_countdown.js,v 1.1 2008/12/01 22:40:55 robloach Exp $

/**
 * jQuery Countdown Drupal behavior.
 */
Drupal.behaviors.jquery_countdown = function() {
  for (countdown in Drupal.settings.jquery_countdown) {
    // Retrieve the options.
    var options = Drupal.settings.jquery_countdown[countdown];

    // Process the date properties if available.
    if (typeof (options.until) != "undefined") {
      options.until = Drupal.jQueryCountdownProcessDate(options.until);
    }
    if (typeof (options.since) != "undefined") {
      options.since = Drupal.jQueryCountdownProcessDate(options.since);
    }
    if (typeof (options.onExpiry) == "string") {
      options.onExpiry = eval(options.onExpiry);
    }
    if (typeof (options.onTick) == "string") {
      options.onTick = eval(options.onTick);
    }

    // Create the countdown element on non-processed elements.
    $(countdown + ':not(.processed)').addClass('processed').countdown(options);
  }
}

/**
 * Process date values for the jQuery Countdown plugin, based on the date type.
 */
Drupal.jQueryCountdownProcessDate = function(dateVal) {
  if (typeof (dateVal) == "string") {
    // Create the Date using the string.
    return new Date(dateVal);
  } else if (typeof (dateVal) == "number") {
    // Return the number of seconds.
    return dateVal;
  } else if (dateVal instanceof Array || dateVal instanceof Object) {
    // Create the Date object from available values, avoiding passing invalid
    // objects.
    var date = new Date();
    for (i = 0; i < 6; i++) {
      dateVal[i] = dateVal[i] || 0;
    }
    date.setFullYear(dateVal[0]);
    date.setMonth(dateVal[1]);
    date.setDate(dateVal[2]);
    date.setHours(dateVal[3]);
    date.setMinutes(dateVal[4]);
    date.setSeconds(dateVal[5]);
    return date;
  }
  return dateVal;
}

==> jquery_countdown-6.x-1.1.tar.gz: jquery_countdown/jquery_countdown.js <==
// $Id: jquery_countdown.js,v 1.1.2.1 2009/01/05 16:54:20 robloach Exp $

/**
 * jQuery Countdown Drupal behavior.
 */
Drupal.behaviors.jquery_countdown = function() {
  for (countdown in Drupal.settings.jquery_countdown) {
    // Retrieve the options.
    var options = Drupal.settings.jquery_countdown[countdown];

    // Process the date properties if available.
    if (typeof (options.until) != "undefined") {
      options.until = Drupal.jQueryCountdownProcessDate(options.until);
    }
    if (typeof (options.since) != "undefined") {
      options.since = Drupal.jQueryCountdownProcessDate(options.since);
    }
    if (typeof (options.onExpiry) == "string") {
      options.onExpiry = eval(options.onExpiry);
    }
    if (typeof (options.onTick) == "string") {
      options.onTick = eval(options.onTick);
    }

    // Create the countdown element on non-processed elements.
    $(countdown + ':not(.jquery-countdown-processed)').addClass('jquery-countdown-processed').countdown(options);
  }
}

/**
 * Process date values for the jQuery Countdown plugin, based on the date type.
 */
Drupal.jQueryCountdownProcessDate = function(dateVal) {
  if (typeof (dateVal) == "string") {
    // Create the Date using the string.
    return new Date(dateVal);
  } else if (typeof (dateVal) == "number") {
    // Return the number of seconds.
    return dateVal;
  } else if (dateVal instanceof Array || dateVal instanceof Object) {
    // Create the Date object from available values, avoiding passing invalid
    // objects.
    var date = new Date();
    for (i = 0; i < 6; i++) {
      dateVal[i] = dateVal[i] || 0;
    }
    date.setFullYear(dateVal[0]);
    date.setMonth(dateVal[1]);
    date.setDate(dateVal[2]);
    date.setHours(dateVal[3]);
    date.setMinutes(dateVal[4]);
    date.setSeconds(dateVal[5]);
    return date;
  }
  return dateVal;
}
